#include "cmGlobalVisualDSP4Generator.h"
#include "cmLocalVisualDSP4Generator.h"
#include "cmGeneratedFileStream.h"
#include "cmMakefile.h"
#include "cmTarget.h"
#include "cmSourceFile.h"

#include "cmSystemTools.h"

cmGlobalVisualDSP4Generator::cmGlobalVisualDSP4Generator()
{
  this->FindMakeProgramFile = "CMakeVDSP4FindMake.cmake";
}

//----------------------------------------------------------------------------
cmGlobalVisualDSP4Generator::~cmGlobalVisualDSP4Generator()
{
}

void cmGlobalVisualDSP4Generator
::GetDocumentation(cmDocumentationEntry& entry) const
{
  entry.name = this->GetName();
  entry.brief = "Generates VisualDSP 4 project files.";
  entry.full =
    "TODO";
}

///! Create a local generator appropriate to this Global Generator
cmLocalGenerator *cmGlobalVisualDSP4Generator::CreateLocalGenerator()
{
  cmLocalGenerator *lg = new cmLocalVisualDSP4Generator;
  lg->SetGlobalGenerator(this);
  return lg;
}

void cmGlobalVisualDSP4Generator::Generate()
{
    // Run all the local generators.
    this->cmGlobalGenerator::Generate();

    cmGeneratedFileStream fout;
    bool opened = false;
    if( this->LocalGenerators.size() > 0 )
    {
        cmMakefile* mf = this->LocalGenerators[0]->GetMakefile();
        const char* activeProject = mf->GetDefinition( "CMAKE_ACTIVE_PROJECT" );
        if( activeProject == 0 )
            activeProject = "UNSET";
        std::string outputDir=mf->GetStartOutputDirectory();
        std::string projectName=mf->GetProjectName();
        std::string projectGroupName = outputDir + "/" + projectName + ".dpg";
        fout.open(projectGroupName.c_str());
        fout
            << "<?xml version=\"1.0\" encoding='ISO-8859-1'?>\n"
            << "<visualdsp-project-group generated=\""
            << cmSystemTools::GetCurrentDateTime( "%a %B %d %H:%M:%S %Y" ) << "\" "
            << "version=\"1.0.0.0\" "
            << "active-project=\"" << activeProject << "\">\n";
        opened = true;
    }

    unsigned int i;
    for(i = 0; i < this->LocalGenerators.size(); ++i)
    {
        cmMakefile* mf = this->LocalGenerators[i]->GetMakefile();
        std::string outputDir=mf->GetStartOutputDirectory();

        cmTargets targets = mf->GetTargets();
        for (cmTargets::iterator l = targets.begin();
             l != targets.end(); l++)
        {
            std::string projectNameFile = outputDir + "/" + l->second.GetName() + ".dpj";
            fout
                << "    <project name=\"" << l->second.GetName() << "\" file=\"" << projectNameFile << "\">\n"
                << "        <dependencies>\n";
            const std::set<cmStdString>& deps = l->second.GetUtilities();
            for(std::set<cmStdString>::const_iterator dep = deps.begin();
                dep != deps.end(); ++dep)
            {
                fout
                    << "            <dependent-project>" << *dep << "</dependent-project>\n";
            }
            fout
                << "        </dependencies>\n";
        }
    }

    if( opened )
    {
        fout
            << "    </project>\n"
            << "</visualdsp-project-group>";
    }
}

void 
cmGlobalVisualDSP4Generator::EnableLanguage(
    std::vector<std::string>const& languages,
    cmMakefile *mf)
{
}
