/*=========================================================================

  Program:   CMake - Cross-Platform Makefile Generator
  Module:    $RCSfile: cmLocalVisualDSP4Generator.cxx,v $
  Language:  C++
  Date:      $Date: 2007/05/09 18:41:38 $
  Version:   $Revision: 1.122 $

  Copyright (c) 2002 Kitware, Inc., Insight Consortium.  All rights reserved.
  See Copyright.txt or http://www.cmake.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notices for more information.

=========================================================================*/
#include "cmGlobalGenerator.h"
#include "cmLocalVisualDSP4Generator.h"
#include "cmGeneratedFileStream.h"
#include "cmMakefile.h"
#include "cmSystemTools.h"
#include "cmSourceFile.h"
#include "cmCacheManager.h"
#include "cmake.h"

#include <cmsys/RegularExpression.hxx>

cmLocalVisualDSP4Generator::cmLocalVisualDSP4Generator()
{
}

cmLocalVisualDSP4Generator::~cmLocalVisualDSP4Generator()
{
}

void cmLocalVisualDSP4Generator::Generate()
{
    std::string outputDir=this->Makefile->GetStartOutputDirectory();
    std::string projectDir=this->Makefile->GetHomeDirectory();
    std::string projectName=this->Makefile->GetProjectName();

    const char* cpuRev = this->Makefile->GetDefinition( "CMAKE_SYSTEM_VERSION" );
    if( cpuRev == 0 )
        cpuRev = "UNSET";
    const char* cpuName = this->Makefile->GetDefinition( "CMAKE_SYSTEM_NAME" );
    if( cpuName == 0 )
        cpuName = "UNSET";
    const char* buildType = this->Makefile->GetDefinition( "CMAKE_BUILD_TYPE" );
    if( buildType == 0 )
        buildType = "UNSET";
    const char* binaryDir = this->Makefile->GetHomeOutputDirectory();
    if( binaryDir == 0 )
        binaryDir = "UNSET";

    //std::vector<std::string> definitions = GetDefinitions
    std::string compilerFlags( this->Makefile->GetDefineFlags() );

    cmTargets& targets = this->Makefile->GetTargets();
    for (cmTargets::iterator l = targets.begin();
         l != targets.end(); l++)
    {
        std::string targetName = l->second.GetName();
        std::string projectNameFile = outputDir + "/" + targetName + ".dpj";
        cmGeneratedFileStream fout2(projectNameFile.c_str());

        std::string extension( "unset" );
        std::string type( "unset" );
        switch( l->second.GetType() )
        {
            case cmTarget::EXECUTABLE:
                extension = ".ldr";
                type = "Loader file";
                break;
            case cmTarget::STATIC_LIBRARY:
                extension = ".dlb";
                type = "Library file";
                break;
            case cmTarget::SHARED_LIBRARY:
            case cmTarget::MODULE_LIBRARY:
            case cmTarget::UTILITY:
            case cmTarget::GLOBAL_TARGET:
            case cmTarget::INSTALL_FILES:
            case cmTarget::INSTALL_PROGRAMS:
            case cmTarget::INSTALL_DIRECTORY:
                break;
        }

        fout2
            << "<?xml version=\"1.0\" encoding='ISO-8859-1'?>\n"
            << "<visualdsp-project schema=\"16\" name=\""
            << targetName << "\" "
            << "file=\"" << projectNameFile << "\" version=\"1\">\n"
            << "    <target>\n"
            << "        <processor revision=\"" << cpuRev << "\">" << cpuName << "</processor>\n"
            << "        <extension>" << extension << "</extension>\n"
            << "        <type>" << type << "</type>\n"
            << "    </target>\n";

        fout2
            << "    <configurations active=\"" << buildType << "\">\n"
            << "        <configuration name=\"" << buildType << "\">\n"
            << "            <output-dir>.</output-dir>\n"
            << "            <changed-property-page-flags>0</changed-property-page-flags>\n"
            << "            <tools>\n"
            << "                <tool type=\"Compiler\">\n"
			<< "                    <option><![CDATA[" << compilerFlags << "]]></option>\n"
			<< "                </tool>\n"
            << "            </tools>\n"
            << "        </configuration>\n"
            << "    </configurations>\n";

        fout2
            << "    <files>\n";
        const std::vector<cmSourceFile*> sourceFiles = this->Makefile->GetSourceFiles();
        for (std::vector<cmSourceFile*>::const_iterator it=sourceFiles.begin(); 
             it!=sourceFiles.end(); it++)
        {
            fout2
                << "        <file name=\"" << (*it)->GetFullPath() << "\">\n"
                << "        </file>\n";
        }
        fout2
            << "    </files>\n"
            << "</visualdsp-project>";
    }
}

